@@ -2,7 +2,13 @@
 from __future__ import annotations
 
 from bluetooth_sensor_state_data import SIGNAL_STRENGTH_KEY
-from sensor_state_data import DeviceClass, DeviceKey, SensorUpdate
+from sensor_state_data import (
+    DeviceClass,
+    DeviceKey,
+    SensorDescription,
+    SensorUpdate,
+    SensorValue,
+)
 from sensor_state_data.data import (
     ATTR_HW_VERSION,
     ATTR_MANUFACTURER,
@@ -14,7 +20,7 @@ from sensor_state_data.data import (
 
 from .parser import SensorPushBluetoothDeviceData
 
-__version__ = "1.2.1"
+__version__ = "1.3.0"
 
 __all__ = [
     "SensorPushBluetoothDeviceData",
@@ -25,9 +31,11 @@ __all__ = [
     "ATTR_NAME",
     "ATTR_SW_VERSION",
     "SIGNAL_STRENGTH_KEY",
+    "SensorDescription",
     "SensorDeviceInfo",
     "DeviceClass",
     "DeviceKey",
     "SensorUpdate",
     "SensorDeviceInfo",
+    "SensorValue",
 ]
